pub mod completion;
/// Provider definitions for LSP `textDocument/publishDiagnostics`.
pub mod diagnostics;
pub mod formatting;
